@@ -257,7 +257,7 @@ public class ParagraphSet extends DocComponent implements HTML4R, PPTX4R, DOCX4R
 		return true;
 	}
 
-	public Vector<P> get_flextable_docx() throws Exception{
+	public Vector<P> get_docx_elt() throws Exception{
 		Vector<P> out = new Vector<P>();
 		
 		if( !validateDOCXComponent() ) 
