@@ -1,4 +1,5 @@
 context("pptx images")
+source("get_relationship.R")
 
 png(filename = "img.png", width = 4*72, height = 4*72)
 plot.new()
@@ -41,4 +42,20 @@ test_that("position no size generate an error", {
   expect_is(doc, "try-error" )
 })
 
+
+
+test_that("image is referenced in relationships", {
+  skip_on_os("solaris")
+  target_file <- tempfile(fileext = ".pptx")
+  target_dir <- tempfile(fileext = "")
+  doc <- pptx( )
+  doc <- addSlide( doc, "Title and Content" )
+  doc <- addImage(doc, "img.png")
+  writeDoc(doc, target_file)
+
+  unzip(zipfile = target_file, exdir = target_dir )
+  rels <- get_relationship(file.path(target_dir, "ppt/slides/_rels/slide1.xml.rels"))
+  expect_equal( sum( grepl( "image$", rels$type ) ), 1 )
+})
+
 unlink("img.png", force = TRUE)
